classdef classifier
%CLASSIFIER abstract classifier method class
%
% A classifier takes a variable number of arguments upon construction. 
% During operation, the classifier takes data and
% produces posterior probabilities of class labels as an N x C matrix for N
% examples and C classes.
% 
% Subclasses should implement the train and test functions.
%
%   Options:
%   'nclasses' : number of classes (determined from data)
%   'verbose'  : output comment if true
%
%   Copyright (c) 2008, Marcel van Gerven
%
%   $Log: classifier.m,v $
%
    properties
             
        verbose = false;       
        nclasses = nan;
    end
    
    methods
        
        function obj = classifier(varargin)
            
            % parse options
            for i=1:2:length(varargin)
                obj.(varargin{i}) = varargin{i+1};
            end
            
        end        
                
    end

    methods(Abstract)
        obj = train(obj,data,design);
        post = test(obj,data);
    end
    
end 
