classdef gslr < classifier
%GSLR group sparsifying logistic regression
%
%   Group sparsifying logistic regression can be used to regularize a
%   logistic regression model with respect to feature groups. As a special
%   case, for multiple datasets, we are performing transfer learning. This
%   is useful for MEG/EEG analysis when we combine the data of multiple
%   subjects/sessions. If we choose p=1 then GSLR reduces to standard l1
%   regularized logistic regression.
%
%   SEE ALSO:
%   regularization_example.m
%   transfer_learning_example.m
%   slr_learn.m
%   slr_learn_transfer.m
%
%   Copyright (c) 2008, Marcel van Gerven
%
%   $Log: gslr.m,v $
%

    properties
        
        model
        options
        diagnostics
      
    end

    methods
       function obj = gslr(varargin)
                            
          obj.options = [];
          
          % parse options
          for i=1:2:length(varargin)
                obj.options.(varargin{i}) = varargin{i+1};
          end

        
       end
       function obj = train(obj,data,design)
           % simply stores input data and design

           % training mode
           if iscell(data)

               if isnan(obj.nclasses), obj.nclasses = max(design{1}(:,1)); end

               % transfer learning
               cdata = cell(1,length(data));
               for c=1:length(data)
                   cdata{c} = [design{c}(:,1) data{c}];
               end

               [obj.model,obj.diagnostics] = slr_learn_transfer(obj.options,cdata);
           else

               if isnan(obj.nclasses), obj.nclasses = max(design(:,1)); end

               [obj.model,obj.diagnostics] = slr_learn(obj.options,[design(:,1) data]);

           end
              
       end
       function post = test(obj,data)       
           
           if iscell(data)
               post = cell(1,length(data));
               for j=1:length(data)
                   post{j} = slr_classify([data{j} ones(size(data{j},1),1)], obj.model{j});
               end
           else       
               post = slr_classify([data ones(size(data,1),1)], obj.model);
           end
       end

    end
end 
