classdef lr < classifier
%LR unregularized logistic regression
%
%   Tries to perform logistic regression using any of the below methods.
%
%   SEE ALSO:
%   minFunc
%   gpml-matlab
%   mnrfit
%   regularize_lr
%
%   Copyright (c) 2008, Marcel van Gerven, Ali Bahramisharif
%
%   $Log: lr.m,v $
%

    properties

        model; % the weight vector
    end

    methods
       function obj = lr(varargin)
                  
           obj = obj@classifier(varargin{:});
                      
       end
       function obj = train(obj,data,design)
            % simply stores input data and design
           
            if iscell(data), error('NB does not take multiple datasets as input'); end

            if isnan(obj.nclasses), obj.nclasses = max(design(:,1)); end

            if exist('minFunc','dir') % proprietary code: gpml-matlab

                nexamples = size(data,1);
                nfeatures = size(data,2)+1;

                classidxs = (1:nexamples)' + (design(:,1) - 1) .* nexamples;
                ptargets = zeros(nexamples,obj.nclasses);
                ptargets(classidxs) = 1;
                targets = (1:nexamples)' + (design(:,1) - 1) * nexamples;

                w = zeros(obj.nclasses,nfeatures);
                
                options.Method='lbfgs';
                w = minFunc(@(w)logreg(w(:),[data ones(size(data,1),1)],targets,ptargets,obj.nclasses),w(:),options);

                obj.model = reshape(w,obj.nclasses,nfeatures);

            elseif exist('gpml-matlab','dir') % proprietary code: gpml-matlab

                nexamples = size(data,1);
                nfeatures = size(data,2)+1;

                classidxs = (1:nexamples)' + (design(:,1) - 1) .* nexamples;
                ptargets = zeros(nexamples,obj.nclasses);
                ptargets(classidxs) = 1;
                targets = (1:nexamples)' + (design(:,1) - 1) * nexamples;

                w = zeros(obj.nclasses,nfeatures);
                w = minimize(w(:),'logreg',50,[data ones(size(data,1),1)],targets,ptargets,obj.nclasses);

                obj.model = reshape(w,obj.nclasses,nfeatures);

            else

                % try unregularized logistic regression
                if license('test','statistics_toolbox') && size(data,2) <= 300 && obj.nclasses == 2

                    % try matlab native code
                    B = mnrfit(data,design(:,1));

                    % construct model
                    obj.model = [ transpose([B(2:end,:); B(1,:)]); zeros(1,size(B,1))];

                else % slow steepest descent

                    cfg.lambda = 0;
                    obj.model = regularize_lr(cfg,[design(:,1) data]);
                    obj.model = obj.model{1};
                end
            end
                     
       end
       function post = test(obj,data)       
           
           if iscell(data)
               post = cell(1,length(data));
               for j=1:length(data)
                   post{j} = slr_classify([data{j} ones(size(data{j},1),1)], obj.model{j});
               end
           else       
               post = slr_classify([data ones(size(data,1),1)], obj.model);
           end
       end              

    end
end 
