classdef pnn < classifier
%PNN probabilistic neural network classifier
%
%   Options
%   'spread' : newpnn parameter that will be optimized if it is a vector
%
%   SEE ALSO:
%   newpnn.m
%
%   NOTE:
%   The FieldTrip replacement of dist.m does not work in this context!
%
%   Copyright (c) 2008, Marcel van Gerven
%
%   $Log: pnn.m,v $
%

    properties
        net; % the neural network
        spread = 1; % modifies nn behaviour; if a vector, will be optimized
        validator = crossvalidator();
        criterion = 'accuracy';       
    end

    methods
       function obj = pnn(varargin)
                  
           obj = obj@classifier(varargin{:});
           
            % check availability
           if ~license('test','neural_network_toolbox')
               error('requires Matlab neural network toolbox');
           end
           
       end
       function obj = train(obj,data,design)
                                  
           if iscell(data), error('PNN does not take multiple datasets as input'); end                       
                     
           if ~isscalar(obj.spread)              
               obj = optimize(obj,data,design(:,1),'variables','spread','values',obj.spread,'validator', ...
                   obj.validator,'criterion',obj.criterion); 
            end
           
            if isnan(obj.nclasses), obj.nclasses = max(design(:,1)); end
            
            obj.net = newpnn(data',ind2vec(design(:,1)'),obj.spread);
                     
       end
       function post = test(obj,data)       
           
           if iscell(data), error('NB does not take multiple datasets as input'); end

           post = sim(obj.net,data')';
       end

    end
end 
