classdef pcanalyzer < preprocessor
%PCANALYZER performs a principal component analysis
%
%   Options:
%   'proportion' : proportion of pc's or number of pc's depending on
%   'proptype'   : 'relative' (proportion,default) or 'absolute' (number)
%
%   NOTE:
%   data should be normalized to have mean zero
%
%   Copyright (c) 2008, Marcel van Gerven
%
%   $Log: pcanalyzer.m,v $
%

    properties
       
        proportion = 1; % proportion of variance accounted for
        proptype = 'relative'; % how to interpret proportion
        accvar; % cumulative variance accounted for per component
        pc; % principal components as column vectors
    end

    methods
    
        function obj = pcanalyzer(varargin)
            
            obj = obj@preprocessor(varargin{:});                        
        end
        
        function obj = train(obj,data,design)

            if iscell(data)
               
                obj.pc = cell(1,length(data));
                obj.accvar = cell(1,length(data));
                
                for c=1:length(data)
                    
                    [obj.pc{c},score,latent] = princomp(data{c});

                    % proportion of the variance that is accounted for
                    obj.accvar{c} = cumsum(latent/sum(latent));

                    % determine how many principal components to use
                    if strcmp(obj.proptype,'absolute')
                        obj.pc{c} = obj.pc{c}(:,1:obj.proportion);
                    else
                        obj.pc{c} = obj.pc{c}(:,1:find(obj.accvar{c} >= obj.proportion,1,'last'));
                    end
                end
            else
                
                [obj.pc,score,latent] = princomp(data);

                % proportion of the variance that is accounted for
                obj.accvar = cumsum(latent/sum(latent));

                % determine how many principal components to use
                if strcmp(obj.proptype,'absolute')
                    obj.pc = obj.pc(:,1:obj.proportion);
                else
                    obj.pc = obj.pc(:,1:find(obj.accvar >= obj.proportion,1,'last'));
                end
            end           
    
        end
        
        function data = test(obj,data)

           if iscell(data)
                
                for c=1:length(data)
                    data{c} = (obj.pc{c}' * data{c}')';
                end
                
           else
               data = (obj.pc' * data')';
           end
        end
        
    end
end 
