classdef standardizer < preprocessor
%STANDARDIZER standardizes data to have mean 0 and standard deviation 1
%
%   Options:
%   'bmean' : if false does not subtract means
%   'bstd'  : if false does not divide by standard deviations
%
%   SEE ALSO:
%   zscore.m
%
%   Copyright (c) 2008, Marcel van Gerven
%
%   $Log: standardizer.m,v $
%

    properties
       means; % mean of each feature based on training data
       stds; % sd of each feature based on training data
       
       bmean = true; % take mean
       bstd = true; % take standard deviation
    end

    methods
        function obj = standardizer(varargin)
            
            obj = obj@preprocessor(varargin{:});                        
            
        end
        function obj = train(obj,data,design)
           
            if iscell(data)
                
                obj.means = cell(1,length(data));
                obj.stds = cell(1,length(data));
                
                if obj.bmean
                    for c=1:length(data)

                        obj.means{c} = nanmean(data{c});

                    end
                end
                
                if obj.bstd
                    for c=1:length(data)

                        obj.stds{c} = mynanstd(data{c});
                        obj.stds{c}(obj.stds{c}==0) = 1;
                       end
                end
                
            else
            
                if obj.bmean
                    obj.means = nanmean(data);
                end
                
                if obj.bstd
                    obj.stds = mynanstd(data);
                    obj.stds(obj.stds==0) = 1;
                end
            end
        end
        
        function data = test(obj,data)            
            
            if iscell(data)
                
                for c=1:length(data)
                    
                    if size(data,2) > 1
                    
                        sz = ones(ndims(obj.means{c})); sz(1) = size(data{c},1);

                        if obj.bmean
                            data{c} = data{c} - repmat(obj.means{c},sz);
                        end
                        
                        if obj.bstd
                            data{c} = data{c} ./ repmat(obj.stds{c},sz);
                        end
                    end
                    
                end
                
            else

                if size(data,2) > 1
                    
                    sz = ones(ndims(obj.means)); sz(1) = size(data,1);

                    if obj.bmean
                        data = data - repmat(obj.means,sz);
                    end
                    
                    if obj.bstd
                        data = data ./ repmat(obj.stds,sz);
                    end
                end
            end
        end
        
    end
end 
