function stat = statistics_crossvalidate(cfg, dat, design)
% STATISTICS_CROSSVALIDATE performs cross-validation using a prespecified
% classifier as given by cfg.classifier.
%
% See also: CROSSVALIDATE
%
% Requires: classification toolbox
%
% Copyright (c) 2007, Marcel van Gerven
% F.C. Donders Centre for Cognitive Neuroimaging, Nijmegen, NL
%
% $Log: statistics_crossvalidate.m,v $
% Revision 1.20  2008/09/22 20:17:44  roboos
% added call to fieldtripdefs to the begin of the function
%
% Revision 1.19  2008/09/18 14:23:39  marvger
% integrated classification_module representation
%
% Revision 1.18  2007/12/19 08:42:57  marvger
% changed naming
%
% Revision 1.17  2007/11/23 13:20:12  marvger
% swap dimensions from features x repetitions to repetitions x features
%
% Revision 1.16  2007/11/13 16:14:01  marvger
% crossvalidate is now part of the classification toolbox
%
% Revision 1.15  2007/11/12 18:46:19  marvger
% *** empty log message ***
%
%
% Revision 1.14  2007/10/10 10:22:07  marvger
% *** empty log message ***

fieldtripdefs

% specify classification procedure

myproc = clfproc({ ...
    preprocessor('prefun',@(x)(log10(x))) ...
    standardizer() ...
    lr() ...
    });

cv = crossvalidator('procedure',myproc,'cvfolds',10,'randomize',true,'verbose',true);

cv = cv.validate(dat',design');
stat = cv.evaluate('metric','accuracy');
